bayespy.nodes.GaussianMarkovChain.initialize_from_prior
=======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianMarkovChain.initialize_from_prior